quantizationtools.QTargetBeat
=============================

.. abjad-lineage:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat

.. autoclass:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.beatspan
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.distances
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.offset_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.q_events
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.q_grid
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.q_grids
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.storage_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.tempo
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.QTargetBeat.__repr__
   :noindex:
